@@ -81,15 +81,22 @@ char Keydata::lastpath[KEYDATA_PATH_SIZE + 1];
 
 void endKeydata();
 
+static unsigned bitsize(void)
+{
+	if(sizeof(void *) > 4)
+		return 2;
+	return 1;
+}
+
 Keydata::Keydata() : 
-MemPager(KEYDATA_PAGER_SIZE)
+MemPager(KEYDATA_PAGER_SIZE * bitsize())
 {
 	link = 0;
 	memset(&keys, 0, sizeof(keys)); 
 }
 
 Keydata::Keydata(const char *path) :
-MemPager(KEYDATA_PAGER_SIZE)
+MemPager(KEYDATA_PAGER_SIZE * bitsize())
 {
 	link = 0;
 	memset(&keys, 0, sizeof(keys));
@@ -97,7 +104,7 @@ MemPager(KEYDATA_PAGER_SIZE)
 }
 
 Keydata::Keydata(Define *pairs, const char *path) :
-MemPager(KEYDATA_PAGER_SIZE)
+MemPager(KEYDATA_PAGER_SIZE * bitsize())
 {
 	link = 0;
 	memset(&keys, 0, sizeof(keys));
