@@ -142,6 +142,21 @@ void *MemPager::alloc(size_t size)
 		size += palign - align;
 #endif
 
+	if(size > pagesize - sizeof(struct _page))
+	{
+		slog.critical("mempager overflow");
+#ifdef	CCXX_EXCEPTIONS
+		if(Thread::getException() == Thread::throwObject)
+			throw this;
+#ifdef	COMMON_STD_EXCEPTION
+		else if(Thread;:getException() == Thread::throwException)
+			Throw Exception("Mempager::alloc(): Memory Overflow");
+#endif
+#else
+		abort();
+#endif
+	}
+
 	if(page->used + size > pagesize)
 	{
 #if defined(HAVE_POSIX_MEMALIGN)
