@@ -135,6 +135,8 @@ bool Socket::check(Family fam)
 		so = socket(fam, SOCK_DGRAM, IPPROTO_UDP);
 		break;
 #endif
+	default:
+		return false;
 	}
 
 	if(so == INVALID_SOCKET)
@@ -735,14 +737,14 @@ Socket::Error Socket::setTimeToLiveByFamily(unsigned char ttl, Family fam)
 		setsockopt(so, IPPROTO_IPV6, IPV6_MULTICAST_HOPS, (char *)&ttl,	sizeof(ttl));
 		return errSuccess;
 #endif
-	default:
+	case IPV4:
 #ifdef	IP_MULTICAST_TTL
 		flags.ttl = ttl;
 		setsockopt(so, IPPROTO_IP, IP_MULTICAST_TTL, (char *)&ttl, sizeof(ttl));
 		return errSuccess;
-#else
-		return error(errServiceUnavailable,"Multicast not supported");
 #endif
+	default:
+		return error(errServiceUnavailable, "Multicast not supported");
 	}
 }
 
@@ -766,13 +768,13 @@ Socket::Error Socket::setLoopbackByFamily(bool enable, Family family)
 		setsockopt(so, IPPROTO_IPV6, IPV6_MULTICAST_LOOP, (char *)&loop, sizeof(loop));
 		return errSuccess;
 #endif
-	default:	
+	case IPV4:
 #ifdef  IP_MULTICAST_LOOP
 		setsockopt(so, IPPROTO_IP, IP_MULTICAST_LOOP, (char *)&loop, sizeof(loop));
 		return errSuccess;
-#else
-		return error(errServiceUnavailable,"Multicast not supported");
 #endif
+	default:
+		return error(errServiceUnavailable,"Multicast not supported");
 	}
 }
 
@@ -1045,7 +1047,6 @@ IPV6Host Socket::getIPV6Local(tpport_t *port) const
 IPV4Host Socket::getIPV4NAT(tpport_t *port) const
 {
 	struct sockaddr_in addr;
-	socklen_t len = sizeof(addr);
 	natResult res;
 
 	if((res=natv4Lookup((int)so, &addr))!=natOK)
@@ -1072,7 +1073,6 @@ IPV4Host Socket::getIPV4NAT(tpport_t *port) const
 IPV6Host Socket::getIPV6NAT(tpport_t *port) const
 {
 	struct sockaddr_in6 addr;
-	socklen_t len = sizeof(addr);
 	natResult res;
 
 	if((res=natv6Lookup(so, &addr))!=natOK)
@@ -1171,7 +1171,7 @@ Socket::Error Socket::setMulticastByFamily(bool enable, Family family)
 		setsockopt(so, IPPROTO_IPV6, IPV6_MULTICAST_IF, (char *)&addr.sin6_addr, sizeof(addr.sin6_addr));
 		return errSuccess;
 #endif
-	default:
+	case IPV4:
 #ifdef	IP_MULTICAST_IF
 		struct sockaddr_in addr4;
 		len = sizeof(addr4);
@@ -1187,9 +1187,9 @@ Socket::Error Socket::setMulticastByFamily(bool enable, Family family)
 
 		setsockopt(so, IPPROTO_IP, IP_MULTICAST_IF, (char *)&addr4.sin_addr, sizeof(addr4.sin_addr));
 		return errSuccess;
-#else
-		return error(errServiceUnavailable,"Multicast not supported");
 #endif
+	default:
+		return error(errServiceUnavailable,"Multicast not supported");
 	}
 }
 
@@ -1295,7 +1295,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 		peer.ipv6.sin6_family = family;
 		break;
 #endif
-	default:
+	case IPV4:
 		peer.ipv4.sin_family = family;
 	}
 	
@@ -1465,7 +1465,7 @@ Socket(fam, SOCK_DGRAM, IPPROTO_UDP)
 		peer.ipv6.sin6_family = family;
 		break;
 #endif
-	default:	
+	case IPV4:	
 		peer.ipv4.sin_family = family;
 	}
 }
@@ -1521,8 +1521,8 @@ UDPSocket::~UDPSocket()
 
 ssize_t UDPSocket::send(const void *buf, size_t len)
 {
-	struct sockaddr *addr;
-	socklen_t alen;
+	struct sockaddr *addr = NULL;
+	socklen_t alen = 0;
 
 	switch(family)
 	{
@@ -1535,6 +1535,9 @@ ssize_t UDPSocket::send(const void *buf, size_t len)
 	case IPV4:
 		addr = (struct sockaddr *)&peer.ipv4;
 		alen = sizeof(struct sockaddr_in);
+		break;
+	default:
+		return -1;
 	}
 
 	if(isConnected())
@@ -1548,9 +1551,9 @@ ssize_t UDPSocket::send(const void *buf, size_t len)
 
 ssize_t UDPSocket::receive(void *buf, size_t len, bool reply)
 {
-	struct sockaddr *addr;
+	struct sockaddr *addr = NULL;
 	struct sockaddr_in senderAddress;  // DMC 2/7/05 ADD for use below.
-	socklen_t alen;
+	socklen_t alen = 0;
 
 	switch(family)
 	{
@@ -1563,6 +1566,9 @@ ssize_t UDPSocket::receive(void *buf, size_t len, bool reply)
 	case IPV4:
 		addr = (struct sockaddr *)&peer.ipv4;
 		alen = sizeof(struct sockaddr_in);
+		break;
+	default:
+		return -1;	
 	}
 
 	if(isConnected() || !reply)
@@ -1789,6 +1795,7 @@ void UDPSocket::setPeer(const char *name)
 #endif
 	case IPV4:
                 memcpy(&peer.ipv4, list->ai_addr, sizeof(peer.ipv4));
+		break;
 	}
 
 	freeaddrinfo(list);
@@ -1834,6 +1841,7 @@ void UDPSocket::setPeer(const char *name)
 #endif
 	case IPV4:
 		setPeer(IPV4Host(namebuf), port);
+		break;
 	}	
 }
 
@@ -1841,7 +1849,7 @@ void UDPSocket::setPeer(const char *name)
 
 void UDPSocket::connect(const char *service)
 {
-	int rtn;
+	int rtn = -1;
 
 	setPeer(service);
 
@@ -1857,6 +1865,7 @@ void UDPSocket::connect(const char *service)
 #endif
 	case IPV4:
 		rtn = ::connect(so, (struct sockaddr *)&peer.ipv4, sizeof(struct sockaddr_in));
+		break;
 	}
 	if(!rtn)
 		Socket::state = CONNECTED;
@@ -2487,7 +2496,6 @@ void TCPStream::connect(const char *target, unsigned mss)
 	char *cp;	
 	struct addrinfo hint, *list = NULL, *next, *first;
 	bool connected = false;
-	socklen_t alen = sizeof(mss);
 
 	snprintf(namebuf, sizeof(namebuf), "%s", target);
 	cp = strrchr(namebuf, '/');
@@ -2614,7 +2622,6 @@ void TCPStream::connect(const IPV4Host &host, tpport_t port, unsigned mss)
 	int rtn;
 	long sockopt;
 	socklen_t len = sizeof(sockopt);
-	socklen_t alen = sizeof(mss);
 
 #ifdef	TCP_MAXSEG
 	if(mss)
@@ -2695,7 +2702,6 @@ void TCPStream::connect(const IPV6Host &host, tpport_t port, unsigned mss)
 	int rtn;
 	long sockopt;
 	socklen_t len = sizeof(sockopt);
-	socklen_t alen = sizeof(mss);
 
 #ifdef	TCP_MAXSEG
 	if(mss)
@@ -3311,9 +3317,7 @@ int TCPSession::waitConnection(timeout_t timer)
 			Socket::state = INITIAL;
 			return -1;
 		}
-	case AVAILABLE:
-	case BOUND:
-	case STREAM:
+	default:
 		break;
 	}
 	Socket::state = CONNECTED;
