@@ -38,8 +38,21 @@
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.  
 
+/**
+ * @file counter.h
+ * @short Generic automatic counter data type template class.
+ **/
+
 namespace ost {
 
+/**
+ * The counter template is used for generic objects which act as
+ * automatic counters.  Each time the object is accessed, the underlying
+ * counted data type is incremented.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short Automatic counter template class.
+ */
 template <typename T>
 class Counter
 {
@@ -47,14 +60,28 @@ protected:
 	T count;
 
 public:
+	/**
+	 * Construct and initialize a counter to zero.
+	 */
 	inline Counter()
 		{count = 0;};
 
-	inline Counter(const Counter &c)
-		{count = c.count;};
+	/**
+	 * Construct a counter with an initial value set for another counter.
+	 *
+	 * @param counter to copy from.
+	 */
+	inline Counter(const Counter &counter)
+		{count = counter.count;};
 
-	inline Counter(T c)
-		{count = c;};
+	/**
+	 * Construct a counter with an initial value of the specified
+	 * data type.
+	 *
+	 * @param initial value to set.
+	 */
+	inline Counter(T initial)
+		{count = initial;};
 
 	inline T& operator=(T c)
 		{counter = c;};
