@@ -38,10 +38,21 @@
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.  
 
+/**
+ * @file pointer.h
+ * @short Template for creating reference count managed smart pointers.
+ **/
+
 namespace ost {
 
+/**
+ * Used to create and manage referece counted pointers.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short reference counted pointer template.
+ */
 template <class T>
-class Pointer
+class __EXPORT Pointer
 {
 protected:
 	unsigned *ptrCount;
